@@ -5,6 +5,6 @@ from libcurses.core import register_fkey, wrapper  # noqa
 from libcurses.getkey import getkey  # noqa
 from libcurses.getline import getline  # noqa
 from libcurses.grid import Grid  # noqa
-from libcurses.logwin import LoggerWindow  # noqa
 from libcurses.mouse import add_mouse_handler, clear_mouse_handlers  # noqa
 from libcurses.mouseevent import MouseEvent  # noqa
+from libcurses.sink import Sink  # noqa
